@@ -2,7 +2,7 @@ use strict;
 use warnings;
 use Feature::Compat::Class;
 
-class WebServer::DirIndex::CSS v0.0.2 {
+class WebServer::DirIndex::CSS v0.0.3 {
 
   field $pretty :param = 0;
 
@@ -10,6 +10,10 @@ class WebServer::DirIndex::CSS v0.0.2 {
 table {
   width: 100%;
 }
+.icon {
+  width: 1.5em;
+  text-align: center;
+}
 .name {
   text-align: left;
 }
@@ -65,6 +69,11 @@ tr:nth-child(even) {
   background: #ccc;
 }
 
+.icon {
+  width: 1.5em;
+  text-align: center;
+}
+
 .size {
   text-align: right;
   padding-right: 1.700em;
